Examples — XlsxWriter Documentation

### Navigation

- index
- next |
- previous |
- XlsxWriter Documentation »

# Examples

The following are some of the examples included in the examples directory of the XlsxWriter distribution.

- Example: Hello World
- Example: Simple Feature Demonstration
- Example: Dates and Times in Excel
- Example: Array formulas
- Example: Merging Cells
- Example: Adding Headers and Footers to Worksheets
- Example: Setting Document Properties
- Example: Unicode Polish in UTF-8
- Example: Unicode Shift JIS

### Navigation

- index
- next |
- previous |
- XlsxWriter Documentation »